@@ -8,7 +8,12 @@ from django.http import HttpResponse
 from django.urls import NoReverseMatch, reverse
 
 from backoffice_extensions.helpers import create_csv_from_data
-from backoffice_extensions.settings import TITLE, URL_NAMESPACE
+from backoffice_extensions.settings import (
+    PRIMARY_BG_COLOR,
+    PRIMARY_COLOR,
+    TITLE,
+    URL_NAMESPACE,
+)
 
 
 class BackOfficeViewMixin:
@@ -21,7 +26,7 @@ class BackOfficeViewMixin:
             raise NotImplementedError("You should specify the template_name attribute.")
 
     def get_extra_context(self) -> Dict:
-        """Adds default context to the backoffice views. Overwrite to add more 
+        """Adds default context to the backoffice views. Overwrite to add more
         context to the view.
         """
         try:
@@ -38,6 +43,8 @@ class BackOfficeViewMixin:
             sign_in = ""
         return {
             "backoffice_title": TITLE,
+            "backoffice_primary_bg_color": PRIMARY_BG_COLOR,
+            "backoffice_primary_color": PRIMARY_COLOR,
             "index_url": index_url,
             "sign_out": sign_out,
             "sign_in": sign_in,
