@@ -1,24 +1,23 @@
 from django import template
 from django.contrib.humanize.templatetags.humanize import intcomma
+from django.core.exceptions import FieldDoesNotExist, ImproperlyConfigured
 from django.db.models import Manager, QuerySet
 from django.db.models.fields.files import ImageFieldFile
 from django.template import defaultfilters
 from django.urls import NoReverseMatch, reverse
 from django.utils.safestring import mark_safe
-from django.utils.translation import gettext_lazy as _
-from django.core.exceptions import ImproperlyConfigured, FieldDoesNotExist
 
 from backoffice_extensions.helpers import StatisticsValue
 from backoffice_extensions.settings import (
     BOOLEAN_FALSE_ICON_CLASSES,
     BOOLEAN_TRUE_ICON_CLASSES,
     DETAILS_URLS,
+    NO_IMAGE_VALUE,
+    NONE_VALUE,
+    SIDEBAR_CONFIG,
     STATUS_FIELDS,
     STATUS_TAG_CLASSES,
     URL_NAMESPACE,
-    SIDEBAR_CONFIG,
-    NONE_VALUE,
-    NO_IMAGE_VALUE,
 )
 
 try:
@@ -42,7 +41,7 @@ def sidebar_menu(context):
         sections_data = []
         for section, data in group.get("sections").items():
             if data.get("permission") is None or (
-                    user and user.has_perm(data.get("permission"))
+                user and user.has_perm(data.get("permission"))
             ):
                 url = reverse(f"{URL_NAMESPACE}:{section.lower()}-list")
                 active = active_path.startswith(url)
